@@ -19,8 +19,8 @@
  *   51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.          *
  ***************************************************************************/
 
-#ifndef _CRON_LOG_MODE_H_
-#define _CRON_LOG_MODE_H_
+#ifndef CRON_LOG_MODE_H
+#define CRON_LOG_MODE_H
 
 /**
  * Cron Log Mode Identifier
@@ -46,9 +46,9 @@ public:
 
     ~CronLogMode();
 
-    Analyzer *createAnalyzer(const QVariant &options = QVariant()) Q_DECL_OVERRIDE;
+    Analyzer *createAnalyzer(const QVariant &options = QVariant()) override;
 
-    QList<LogFile> createLogFiles() Q_DECL_OVERRIDE;
+    QList<LogFile> createLogFiles() override;
 };
 
-#endif // _CRON_LOG_MODE_H_
+#endif // _CRON_LOG_MODE_H
